/// <reference types="react" />
import { Control, FieldErrors } from "react-hook-form";
import { GridSpacing, GridProps } from "@material-ui/core";
import { MuiRhfTextFieldProps, MuiRhfSelectProps, MuiRhfCheckboxProps, MuiRhfAutocompleteProps } from "../fields";
/** react-hook-form watch */
export declare type RhfWatch = (names?: string | string[]) => any;
/** Form field key component mapping */
export declare type MuiRhfFieldComponentMap = {
    textField: React.FC<MuiRhfTextFieldProps>;
    select: React.FC<MuiRhfSelectProps>;
    checkbox: React.FC<MuiRhfCheckboxProps>;
    autocomplete: React.FC<MuiRhfAutocompleteProps>;
};
/** Form */
declare type MuiRhfFormFieldCondition = {
    [key: string]: (value: unknown) => boolean;
};
declare type MuiRhfFormFieldConditionalProps = {
    [key: string]: [string, (value: unknown) => unknown];
};
declare type MuiRhfFormField = {
    name: string;
    label?: string;
    props?: any;
    type?: keyof MuiRhfFieldComponentMap;
    gridProps?: Pick<GridProps, "xs" | "sm" | "md" | "lg" | "xl">;
    condition?: MuiRhfFormFieldCondition;
    conditions?: MuiRhfFormFieldCondition;
    conditionalProps?: MuiRhfFormFieldConditionalProps;
};
declare type MuiRhfFormHeader = {
    title?: string;
};
export declare type MuiRhfFormProps = {
    fields: MuiRhfFormField[][];
    headers?: MuiRhfFormHeader[];
    spacing?: GridSpacing;
    watch?: RhfWatch;
    control: Control;
    errors: FieldErrors;
};
export {};
